#
# spec file for package python-astunparse
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-astunparse
Version:        1.6.3
Release:        150400.9.3.1
Summary:        An AST unparser for Python
License:        BSD-3-Clause AND Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/simonpercivall/astunparse
Source:         https://files.pythonhosted.org/packages/source/a/astunparse/astunparse-%{version}.tar.gz
# PATCH-FIX-UPSTREAM astunparse-pr57-py39.patch -- gh#simonpercivall/astunparse#57
Patch0:         astunparse-pr57-py39.patch
# https://github.com/simonpercivall/astunparse/pull/59
Patch1:         fix-formatted-value.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.6.1}
BuildRequires:  %{python_module wheel >= 0.23.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six >= 1.6.1
Requires:       python-wheel >= 0.23.0
%python_subpackages

%description
This is a factored out version of ``unparse`` found in the Python
source distribution; under Demo/parser in Python 2 and under
Tools/parser in Python 3.

This library is single-source compatible with Python 2.6 through
Python 3.5. It is authored by the Python core developers; I have
simply merged the Python 2.7 and the Python 3.5 source and test
suites, and added a wrapper. This factoring out is to provide a
library implementation that supports both versions.

Added to this is a pretty-printing dump utility function.

%prep
%autosetup -p1 -n astunparse-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# fails to parse the 32bit stdlib
%if "%_lib" == "lib64"
%check
%pyunittest discover -v
%endif

%files %{python_files}
%doc AUTHORS.rst README.rst HISTORY.rst
%license LICENSE
%{python_sitelib}/astunparse
%{python_sitelib}/astunparse-%{version}*-info

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Fri Feb 17 2023 dmueller@suse.com
- need to turn off noarch to be able to skip tests on 32bit arches
* Thu Feb 16 2023 dmueller@suse.com
- add fix-formatted-value.patch
- skip tests on 32bit platforms
* Fri Sep 10 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sun Apr 18 2021 code@bnavigator.de
- Add astunparse-pr57-py39.patch by Fedora maintainer for Python
  3.9 support -- gh#simonpercivall/astunparse#57
* Fri Jan 17 2020 mcalabkova@suse.com
- update to 1.6.3
  * Add full support for Python 3.8
* Wed Mar  6 2019 tchvatal@suse.com
- Update to 1.6.2:
  * Python 3.7 compatibility
  * Fix the roundtripping of very complex f-strings.
  * Add support for the Constant node in Python 3.8
  * Add tests to the sdist
- Execute tests
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Fri Aug  3 2018 toddrme2178@gmail.com
- Initial version
